@@ -1,91 +1,71 @@
-# -*- coding: utf-8 -*-
-
-########################################################################
-#
-# License: BSD
-# Created: December 15, 2004
-# Author:  Ivan Vilata i Balaguer - reverse:net.selidor@ivan
-#
-# $Id$
-#
-########################################################################
-
 """Unit test for the Time datatypes."""
 
-from __future__ import print_function
-from __future__ import absolute_import
 
-import numpy
+import numpy as np
 
-import tables
+import tables as tb
 from tables.tests import common
-from tables.tests.common import allequal
-from tables.tests.common import unittest, test_filename
-from tables.tests.common import PyTablesTestCase as TestCase
-from six.moves import range
 
 
-class LeafCreationTestCase(common.TempFileMixin, TestCase):
+class LeafCreationTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Tests creating Tables, VLArrays an EArrays with Time data."""
 
     def test00_UnidimLeaves(self):
         """Creating new nodes with unidimensional time elements."""
 
         # Table creation.
-        class MyTimeRow(tables.IsDescription):
-            intcol = tables.IntCol()
-            t32col = tables.Time32Col()
-            t64col = tables.Time64Col()
+        class MyTimeRow(tb.IsDescription):
+            intcol = tb.IntCol()
+            t32col = tb.Time32Col()
+            t64col = tb.Time64Col()
 
         self.h5file.create_table('/', 'table', MyTimeRow)
 
         # VLArray creation.
-        self.h5file.create_vlarray('/', 'vlarray4', tables.Time32Atom())
-        self.h5file.create_vlarray('/', 'vlarray8', tables.Time64Atom())
+        self.h5file.create_vlarray('/', 'vlarray4', tb.Time32Atom())
+        self.h5file.create_vlarray('/', 'vlarray8', tb.Time64Atom())
 
         # EArray creation.
-        self.h5file.create_earray('/', 'earray4',
-                                  tables.Time32Atom(), shape=(0,))
-        self.h5file.create_earray('/', 'earray8',
-                                  tables.Time64Atom(), shape=(0,))
+        self.h5file.create_earray('/', 'earray4', tb.Time32Atom(), shape=(0,))
+        self.h5file.create_earray('/', 'earray8', tb.Time64Atom(), shape=(0,))
 
     def test01_MultidimLeaves(self):
         """Creating new nodes with multidimensional time elements."""
 
         # Table creation.
-        class MyTimeRow(tables.IsDescription):
-            intcol = tables.IntCol(shape=(2, 1))
-            t32col = tables.Time32Col(shape=(2, 1))
-            t64col = tables.Time64Col(shape=(2, 1))
+        class MyTimeRow(tb.IsDescription):
+            intcol = tb.IntCol(shape=(2, 1))
+            t32col = tb.Time32Col(shape=(2, 1))
+            t64col = tb.Time64Col(shape=(2, 1))
         self.h5file.create_table('/', 'table', MyTimeRow)
 
         # VLArray creation.
         self.h5file.create_vlarray(
-            '/', 'vlarray4', tables.Time32Atom(shape=(2, 1)))
+            '/', 'vlarray4', tb.Time32Atom(shape=(2, 1)))
         self.h5file.create_vlarray(
-            '/', 'vlarray8', tables.Time64Atom(shape=(2, 1)))
+            '/', 'vlarray8', tb.Time64Atom(shape=(2, 1)))
 
         # EArray creation.
         self.h5file.create_earray(
-            '/', 'earray4', tables.Time32Atom(), shape=(0, 2, 1))
+            '/', 'earray4', tb.Time32Atom(), shape=(0, 2, 1))
         self.h5file.create_earray(
-            '/', 'earray8', tables.Time64Atom(), shape=(0, 2, 1))
+            '/', 'earray8', tb.Time64Atom(), shape=(0, 2, 1))
 
 
-class OpenTestCase(common.TempFileMixin, TestCase):
+class OpenTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Tests opening a file with Time nodes."""
 
     # The description used in the test Table.
-    class MyTimeRow(tables.IsDescription):
-        t32col = tables.Time32Col(shape=(2, 1))
-        t64col = tables.Time64Col(shape=(2, 1))
+    class MyTimeRow(tb.IsDescription):
+        t32col = tb.Time32Col(shape=(2, 1))
+        t64col = tb.Time64Col(shape=(2, 1))
 
     # The atoms used in the test VLArrays.
-    myTime32Atom = tables.Time32Atom(shape=(2, 1))
-    myTime64Atom = tables.Time64Atom(shape=(2, 1))
+    myTime32Atom = tb.Time32Atom(shape=(2, 1))
+    myTime64Atom = tb.Time64Atom(shape=(2, 1))
 
     def setUp(self):
-        super(OpenTestCase, self).setUp()
+        super().setUp()
 
         # Create test Table.
         self.h5file.create_table('/', 'table', self.MyTimeRow)
@@ -153,22 +133,22 @@ class OpenTestCase(common.TempFileMixin, TestCase):
             "Atom types do not match.")
 
 
-class CompareTestCase(common.TempFileMixin, TestCase):
+class CompareTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Tests whether stored and retrieved time data is kept the same."""
 
     # The description used in the test Table.
-    class MyTimeRow(tables.IsDescription):
-        t32col = tables.Time32Col(pos=0)
-        t64col = tables.Time64Col(shape=(2,), pos = 1)
+    class MyTimeRow(tb.IsDescription):
+        t32col = tb.Time32Col(pos=0)
+        t64col = tb.Time64Col(shape=(2,), pos=1)
 
     # The atoms used in the test VLArrays.
-    myTime32Atom = tables.Time32Atom(shape=(2,))
-    myTime64Atom = tables.Time64Atom(shape=(2,))
+    myTime32Atom = tb.Time32Atom(shape=(2,))
+    myTime64Atom = tb.Time64Atom(shape=(2,))
 
     def test00_Compare32VLArray(self):
         """Comparing written 32-bit time data with read data in a VLArray."""
 
-        wtime = numpy.array((1234567890,) * 2, numpy.int32)
+        wtime = np.array((1_234_567_890,) * 2, np.int32)
 
         # Create test VLArray with data.
         vla = self.h5file.create_vlarray('/', 'test', self.myTime32Atom)
@@ -178,13 +158,13 @@ class CompareTestCase(common.TempFileMixin, TestCase):
         # Check the written data.
         rtime = self.h5file.root.test.read()[0][0]
         self.h5file.close()
-        self.assertTrue(allequal(rtime, wtime),
+        self.assertTrue(common.allequal(rtime, wtime),
                         "Stored and retrieved values do not match.")
 
     def test01_Compare64VLArray(self):
         """Comparing written 64-bit time data with read data in a VLArray."""
 
-        wtime = numpy.array((1234567890.123456,) * 2, numpy.float64)
+        wtime = np.array((1_234_567_890.123456,) * 2, np.float64)
 
         # Create test VLArray with data.
         vla = self.h5file.create_vlarray('/', 'test', self.myTime64Atom)
@@ -194,7 +174,7 @@ class CompareTestCase(common.TempFileMixin, TestCase):
         # Check the written data.
         rtime = self.h5file.root.test.read()[0][0]
         self.h5file.close()
-        self.assertTrue(allequal(rtime, wtime),
+        self.assertTrue(common.allequal(rtime, wtime),
                         "Stored and retrieved values do not match.")
 
     def test01b_Compare64VLArray(self):
@@ -219,19 +199,19 @@ class CompareTestCase(common.TempFileMixin, TestCase):
         arr = self.h5file.root.test.read()
         self.h5file.close()
 
-        arr = numpy.array(arr)
-        orig_val = numpy.arange(0, nrows * 2, dtype=numpy.int32) + 0.012
+        arr = np.array(arr)
+        orig_val = np.arange(0, nrows * 2, dtype=np.int32) + 0.012
         orig_val.shape = (nrows, 1, 2)
         if common.verbose:
             print("Original values:", orig_val)
             print("Retrieved values:", arr)
-        self.assertTrue(allequal(arr, orig_val),
+        self.assertTrue(common.allequal(arr, orig_val),
                         "Stored and retrieved values do not match.")
 
     def test02_CompareTable(self):
         """Comparing written time data with read data in a Table."""
 
-        wtime = 1234567890.123456
+        wtime = 1_234_567_890.123456
 
         # Create test Table with data.
         tbl = self.h5file.create_table('/', 'test', self.MyTimeRow)
@@ -248,8 +228,8 @@ class CompareTestCase(common.TempFileMixin, TestCase):
         self.assertEqual(recarr['t32col'][0], int(wtime),
                          "Stored and retrieved values do not match.")
 
-        comp = (recarr['t64col'][0] == numpy.array((wtime, wtime)))
-        self.assertTrue(numpy.alltrue(comp),
+        comp = (recarr['t64col'][0] == np.array((wtime, wtime)))
+        self.assertTrue(np.alltrue(comp),
                         "Stored and retrieved values do not match.")
 
     def test02b_CompareTable(self):
@@ -278,37 +258,38 @@ class CompareTestCase(common.TempFileMixin, TestCase):
         self.h5file.close()
 
         # Time32 column.
-        orig_val = numpy.arange(nrows, dtype=numpy.int32)
+        orig_val = np.arange(nrows, dtype=np.int32)
         if common.verbose:
             print("Original values:", orig_val)
             print("Retrieved values:", recarr['t32col'][:])
-        self.assertTrue(numpy.alltrue(recarr['t32col'][:] == orig_val),
+        self.assertTrue(np.alltrue(recarr['t32col'][:] == orig_val),
                         "Stored and retrieved values do not match.")
 
         # Time64 column.
-        orig_val = numpy.arange(0, nrows * 2, dtype=numpy.int32) + 0.012
+        orig_val = np.arange(0, nrows * 2, dtype=np.int32) + 0.012
         orig_val.shape = (nrows, 2)
         if common.verbose:
             print("Original values:", orig_val)
             print("Retrieved values:", recarr['t64col'][:])
-        self.assertTrue(allequal(recarr['t64col'][:], orig_val, numpy.float64),
-                        "Stored and retrieved values do not match.")
+        self.assertTrue(
+            common.allequal(recarr['t64col'][:], orig_val, np.float64),
+            "Stored and retrieved values do not match.")
 
     def test03_Compare64EArray(self):
         """Comparing written 64-bit time data with read data in an EArray."""
 
-        wtime = 1234567890.123456
+        wtime = 1_234_567_890.123456
 
         # Create test EArray with data.
         ea = self.h5file.create_earray(
-            '/', 'test', tables.Time64Atom(), shape=(0,))
+            '/', 'test', tb.Time64Atom(), shape=(0,))
         ea.append((wtime,))
         self._reopen()
 
         # Check the written data.
         rtime = self.h5file.root.test[0]
         self.h5file.close()
-        self.assertTrue(allequal(rtime, wtime),
+        self.assertTrue(common.allequal(rtime, wtime),
                         "Stored and retrieved values do not match.")
 
     def test03b_Compare64EArray(self):
@@ -316,7 +297,7 @@ class CompareTestCase(common.TempFileMixin, TestCase):
         EArray."""
 
         # Create test EArray with data.
-        ea = self.h5file.create_earray('/', 'test', tables.Time64Atom(),
+        ea = self.h5file.create_earray('/', 'test', tb.Time64Atom(),
                                        shape=(0, 2))
 
         # Size of the test.
@@ -334,24 +315,24 @@ class CompareTestCase(common.TempFileMixin, TestCase):
         arr = self.h5file.root.test.read()
         self.h5file.close()
 
-        orig_val = numpy.arange(0, nrows * 2, dtype=numpy.int32) + 0.012
+        orig_val = np.arange(0, nrows * 2, dtype=np.int32) + 0.012
         orig_val.shape = (nrows, 2)
         if common.verbose:
             print("Original values:", orig_val)
             print("Retrieved values:", arr)
-        self.assertTrue(allequal(arr, orig_val),
+        self.assertTrue(common.allequal(arr, orig_val),
                         "Stored and retrieved values do not match.")
 
 
-class UnalignedTestCase(common.TempFileMixin, TestCase):
+class UnalignedTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Tests writing and reading unaligned time values in a table."""
 
     # The description used in the test Table.
     # Time fields are unaligned because of 'i8col'.
-    class MyTimeRow(tables.IsDescription):
-        i8col = tables.Int8Col(pos=0)
-        t32col = tables.Time32Col(pos=1)
-        t64col = tables.Time64Col(shape=(2,), pos = 2)
+    class MyTimeRow(tb.IsDescription):
+        i8col = tb.Int8Col(pos=0)
+        t32col = tb.Time32Col(pos=1)
+        t64col = tb.Time64Col(shape=(2,), pos=2)
 
     def test00_CompareTable(self):
         """Comparing written unaligned time data with read data in a Table."""
@@ -380,42 +361,43 @@ class UnalignedTestCase(common.TempFileMixin, TestCase):
         self.h5file.close()
 
         # Int8 column.
-        orig_val = numpy.arange(nrows, dtype=numpy.int8)
+        orig_val = np.arange(nrows, dtype=np.int8)
         if common.verbose:
             print("Original values:", orig_val)
             print("Retrieved values:", recarr['i8col'][:])
-        self.assertTrue(numpy.alltrue(recarr['i8col'][:] == orig_val),
+        self.assertTrue(np.alltrue(recarr['i8col'][:] == orig_val),
                         "Stored and retrieved values do not match.")
 
         # Time32 column.
-        orig_val = numpy.arange(nrows, dtype=numpy.int32)
+        orig_val = np.arange(nrows, dtype=np.int32)
         if common.verbose:
             print("Original values:", orig_val)
             print("Retrieved values:", recarr['t32col'][:])
-        self.assertTrue(numpy.alltrue(recarr['t32col'][:] == orig_val),
+        self.assertTrue(np.alltrue(recarr['t32col'][:] == orig_val),
                         "Stored and retrieved values do not match.")
 
         # Time64 column.
-        orig_val = numpy.arange(0, nrows * 2, dtype=numpy.int32) + 0.012
+        orig_val = np.arange(0, nrows * 2, dtype=np.int32) + 0.012
         orig_val.shape = (nrows, 2)
         if common.verbose:
             print("Original values:", orig_val)
             print("Retrieved values:", recarr['t64col'][:])
-        self.assertTrue(allequal(recarr['t64col'][:], orig_val, numpy.float64),
-                        "Stored and retrieved values do not match.")
+        self.assertTrue(common.allequal(
+            recarr['t64col'][:], orig_val, np.float64),
+            "Stored and retrieved values do not match.")
 
 
-class BigEndianTestCase(TestCase):
+class BigEndianTestCase(common.PyTablesTestCase):
     """Tests for reading big-endian time values in arrays and nested tables."""
 
     def setUp(self):
-        super(BigEndianTestCase, self).setUp()
-        filename = test_filename('times-nested-be.h5')
-        self.h5file = tables.open_file(filename, 'r')
+        super().setUp()
+        filename = common.test_filename('times-nested-be.h5')
+        self.h5file = tb.open_file(filename, 'r')
 
     def tearDown(self):
         self.h5file.close()
-        super(BigEndianTestCase, self).tearDown()
+        super().tearDown()
 
     def test00a_Read32Array(self):
         """Checking Time32 type in arrays."""
@@ -424,14 +406,14 @@ class BigEndianTestCase(TestCase):
         earr = self.h5file.root.earr32[:]
 
         # Generate the expected Time32 array.
-        start = 1178896298
+        start = 1_178_896_298
         nrows = 10
-        orig_val = numpy.arange(start, start + nrows, dtype=numpy.int32)
+        orig_val = np.arange(start, start + nrows, dtype=np.int32)
 
         if common.verbose:
             print("Retrieved values:", earr)
             print("Should look like:", orig_val)
-        self.assertTrue(numpy.alltrue(earr == orig_val),
+        self.assertTrue(np.alltrue(earr == orig_val),
                         "Retrieved values do not match the expected values.")
 
     def test00b_Read64Array(self):
@@ -441,14 +423,14 @@ class BigEndianTestCase(TestCase):
         earr = self.h5file.root.earr64[:]
 
         # Generate the expected Time64 array.
-        start = 1178896298.832258
+        start = 1_178_896_298.832258
         nrows = 10
-        orig_val = numpy.arange(start, start + nrows, dtype=numpy.float64)
+        orig_val = np.arange(start, start + nrows, dtype=np.float64)
 
         if common.verbose:
             print("Retrieved values:", earr)
             print("Should look like:", orig_val)
-        self.assertTrue(numpy.allclose(earr, orig_val, rtol=1.e-15),
+        self.assertTrue(np.allclose(earr, orig_val, rtol=1.e-15),
                         "Retrieved values do not match the expected values.")
 
     def test01a_ReadPlainColumn(self):
@@ -459,14 +441,14 @@ class BigEndianTestCase(TestCase):
         t32 = tbl.cols.t32[:]
 
         # Generate the expected Time32 array.
-        start = 1178896298
+        start = 1_178_896_298
         nrows = 10
-        orig_val = numpy.arange(start, start + nrows, dtype=numpy.int32)
+        orig_val = np.arange(start, start + nrows, dtype=np.int32)
 
         if common.verbose:
             print("Retrieved values:", t32)
             print("Should look like:", orig_val)
-        self.assertTrue(numpy.alltrue(t32 == orig_val),
+        self.assertTrue(np.alltrue(t32 == orig_val),
                         "Retrieved values do not match the expected values.")
 
     def test01b_ReadNestedColumn(self):
@@ -477,14 +459,14 @@ class BigEndianTestCase(TestCase):
         t64 = tbl.cols.nested.t64[:]
 
         # Generate the expected Time64 array.
-        start = 1178896298.832258
+        start = 1_178_896_298.832258
         nrows = 10
-        orig_val = numpy.arange(start, start + nrows, dtype=numpy.float64)
+        orig_val = np.arange(start, start + nrows, dtype=np.float64)
 
         if common.verbose:
             print("Retrieved values:", t64)
             print("Should look like:", orig_val)
-        self.assertTrue(numpy.allclose(t64, orig_val, rtol=1.e-15),
+        self.assertTrue(np.allclose(t64, orig_val, rtol=1.e-15),
                         "Retrieved values do not match the expected values.")
 
     def test02_ReadNestedColumnTwice(self):
@@ -493,18 +475,18 @@ class BigEndianTestCase(TestCase):
         # Check the written data.
         tbl = self.h5file.root.tbl
         dummy = tbl.cols.nested.t64[:]
-        self.assertTrue(dummy is not None)
+        self.assertIsNotNone(dummy)
         t64 = tbl.cols.nested.t64[:]
 
         # Generate the expected Time64 array.
-        start = 1178896298.832258
+        start = 1_178_896_298.832258
         nrows = 10
-        orig_val = numpy.arange(start, start + nrows, dtype=numpy.float64)
+        orig_val = np.arange(start, start + nrows, dtype=np.float64)
 
         if common.verbose:
             print("Retrieved values:", t64)
             print("Should look like:", orig_val)
-        self.assertTrue(numpy.allclose(t64, orig_val, rtol=1.e-15),
+        self.assertTrue(np.allclose(t64, orig_val, rtol=1.e-15),
                         "Retrieved values do not match the expected values.")
 
 
@@ -514,13 +496,13 @@ def suite():
     Returns a test suite consisting of all the test cases in the module.
     """
 
-    theSuite = unittest.TestSuite()
+    theSuite = common.unittest.TestSuite()
 
-    theSuite.addTest(unittest.makeSuite(LeafCreationTestCase))
-    theSuite.addTest(unittest.makeSuite(OpenTestCase))
-    theSuite.addTest(unittest.makeSuite(CompareTestCase))
-    theSuite.addTest(unittest.makeSuite(UnalignedTestCase))
-    theSuite.addTest(unittest.makeSuite(BigEndianTestCase))
+    theSuite.addTest(common.unittest.makeSuite(LeafCreationTestCase))
+    theSuite.addTest(common.unittest.makeSuite(OpenTestCase))
+    theSuite.addTest(common.unittest.makeSuite(CompareTestCase))
+    theSuite.addTest(common.unittest.makeSuite(UnalignedTestCase))
+    theSuite.addTest(common.unittest.makeSuite(BigEndianTestCase))
 
     return theSuite
 
@@ -529,11 +511,4 @@ if __name__ == '__main__':
     import sys
     common.parse_argv(sys.argv)
     common.print_versions()
-    unittest.main(defaultTest='suite')
-
-
-## Local Variables:
-## mode: python
-## py-indent-offset: 4
-## tab-width: 4
-## End:
+    common.unittest.main(defaultTest='suite')
