@@ -1,37 +1,30 @@
-# -*- coding: utf-8 -*-
-
-import os
 import sys
-import time
 import tempfile
 import warnings
+from pathlib import Path
+from time import perf_counter as clock
 
-import tables
-from tables import Group, Leaf, Table, Array
-from tables import StringCol, IntCol, Int16Col, FloatCol, Float32Col
-
+import tables as tb
 from tables.tests import common
-from tables.tests.common import unittest
-from tables.tests.common import PyTablesTestCase as TestCase
 
 
 # Test Record class
-class Record(tables.IsDescription):
-    var1 = StringCol(itemsize=4)  # 4-character String
-    var2 = IntCol()              # integer
-    var3 = Int16Col()            # short integer
-    var4 = FloatCol()            # double (double-precision)
-    var5 = Float32Col()          # float  (single-precision)
+class Record(tb.IsDescription):
+    var1 = tb.StringCol(itemsize=4)  # 4-character String
+    var2 = tb.IntCol()              # integer
+    var3 = tb.Int16Col()            # short integer
+    var4 = tb.FloatCol()            # double (double-precision)
+    var5 = tb.Float32Col()          # float  (single-precision)
 
 
-class TreeTestCase(common.TempFileMixin, TestCase):
+class TreeTestCase(common.TempFileMixin, common.PyTablesTestCase):
     open_mode = "w"
     title = "This is the table title"
     expectedrows = 10
     appendrows = 5
 
     def setUp(self):
-        super(TreeTestCase, self).setUp()
+        super().setUp()
 
         # Create an instance of HDF5 Table
         self.populateFile()
@@ -79,7 +72,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
             print('\n', '-=' * 30)
             print("Running %s.test00_getNode..." % self.__class__.__name__)
 
-        self.h5file = tables.open_file(self.h5fname, "r")
+        self.h5file = tb.open_file(self.h5fname, "r")
         nodelist = ['/', '/table0', '/group0/var1', '/group0/group1/var4']
         nodenames = []
         for node in nodelist:
@@ -141,7 +134,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
             for name in nodenames:
                 try:
                     object = self.h5file.get_node(group, name, 'Array')
-                except:
+                except Exception:
                     pass
                 else:
                     nodearrays.append(object._v_pathname)
@@ -161,24 +154,24 @@ class TreeTestCase(common.TempFileMixin, TestCase):
             print("Running %s.test01_getNodeClass..." %
                   self.__class__.__name__)
 
-        self.h5file = tables.open_file(self.h5fname, "r")
+        self.h5file = tb.open_file(self.h5fname, "r")
 
         # This tree ways of get_node usage should return a table instance
         table = self.h5file.get_node("/group0/table1")
-        self.assertIsInstance(table, Table)
+        self.assertIsInstance(table, tb.Table)
         table = self.h5file.get_node("/group0", "table1")
-        self.assertIsInstance(table, Table)
+        self.assertIsInstance(table, tb.Table)
         table = self.h5file.get_node(self.h5file.root.group0, "table1")
-        self.assertIsInstance(table, Table)
+        self.assertIsInstance(table, tb.Table)
 
         # This should return an array instance
         arr = self.h5file.get_node("/group0/var1")
-        self.assertIsInstance(arr, Array)
-        self.assertIsInstance(arr, Leaf)
+        self.assertIsInstance(arr, tb.Array)
+        self.assertIsInstance(arr, tb.Leaf)
 
         # And this a Group
         group = self.h5file.get_node("/group0", "group1", "Group")
-        self.assertIsInstance(group, Group)
+        self.assertIsInstance(group, tb.Group)
 
     def test02_listNodes(self):
         """Checking the File.list_nodes() method"""
@@ -189,7 +182,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
 
         # Made the warnings to raise an error
         # warnings.filterwarnings("error", category=UserWarning)
-        self.h5file = tables.open_file(self.h5fname, "r")
+        self.h5file = tb.open_file(self.h5fname, "r")
 
         self.assertRaises(TypeError,
                           self.h5file.list_nodes, '/', 'NoSuchClass')
@@ -201,7 +194,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
         for node in nodelist:
             try:
                 objectlist = self.h5file.list_nodes(node)
-            except:
+            except Exception:
                 pass
             else:
                 objects.extend(objectlist)
@@ -219,7 +212,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
         for node in objects:
             try:
                 objectlist = self.h5file.list_nodes(node)
-            except:
+            except Exception:
                 pass
             else:
                 for object in objectlist:
@@ -285,7 +278,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
             print('\n', '-=' * 30)
             print("Running %s.test02b_iterNodes..." % self.__class__.__name__)
 
-        self.h5file = tables.open_file(self.h5fname, "r")
+        self.h5file = tb.open_file(self.h5fname, "r")
 
         self.assertRaises(TypeError,
                           self.h5file.list_nodes, '/', 'NoSuchClass')
@@ -297,7 +290,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
         for node in nodelist:
             try:
                 objectlist = [o for o in self.h5file.iter_nodes(node)]
-            except:
+            except Exception:
                 pass
             else:
                 objects.extend(objectlist)
@@ -315,7 +308,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
         for node in objects:
             try:
                 objectlist = [o for o in self.h5file.iter_nodes(node)]
-            except:
+            except Exception:
                 pass
             else:
                 for object in objectlist:
@@ -382,7 +375,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
             print("Running %s.test03_TraverseTree..." %
                   self.__class__.__name__)
 
-        self.h5file = tables.open_file(self.h5fname, "r")
+        self.h5file = tb.open_file(self.h5fname, "r")
         groups = []
         tables_ = []
         arrays = []
@@ -436,7 +429,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
             print('\n', '-=' * 30)
             print("Running %s.test04_walkNodes..." % self.__class__.__name__)
 
-        self.h5file = tables.open_file(self.h5fname, "r")
+        self.h5file = tb.open_file(self.h5fname, "r")
 
         self.assertRaises(TypeError, next,
                           self.h5file.walk_nodes('/', 'NoSuchClass'))
@@ -503,7 +496,7 @@ class TreeTestCase(common.TempFileMixin, TestCase):
             print('\n', '-=' * 30)
             print("Running %s.test05_dir..." % self.__class__.__name__)
 
-        self.h5file = tables.open_file(self.h5fname, "r")
+        self.h5file = tb.open_file(self.h5fname, "r")
 
         """
         h5file nodes:
@@ -513,16 +506,17 @@ class TreeTestCase(common.TempFileMixin, TestCase):
         """
         root_dir = dir(self.h5file.root)
 
-        ## Check some regular attributes.
-        #
+        # Check some regular attributes.
+
         self.assertIn('_v_children', root_dir)
         self.assertIn('_v_attrs', root_dir)
+        self.assertIn('_v_groups', root_dir)
         self.assertIn('_g_get_child_group_class', root_dir)
         self.assertIn('_g_get_child_group_class', root_dir)
         self.assertIn('_f_close', root_dir)
 
-        ## Check children nodes.
-        #
+        # Check children nodes.
+
         self.assertIn('group0', root_dir)
         self.assertIn('table0', root_dir)
         self.assertIn('var1', root_dir)
@@ -552,12 +546,41 @@ class TreeTestCase(common.TempFileMixin, TestCase):
         if common.verbose:
             print("Group.__dir__ test passed")
 
+    def test06_v_groups(self):
+        """Checking Group._v_groups"""
 
-class DeepTreeTestCase(common.TempFileMixin, TestCase):
+        if common.verbose:
+            print('\n', '-=' * 30)
+            print("Running %s.test06_v_groups..." % self.__class__.__name__)
+
+        self.h5file = tb.open_file(self.h5fname, "r")
+
+        """
+        h5file nodes:
+        '/table0', '/var1', '/var4'
+        '/group0/table1', '/group0/var1', '/group0/var4',
+        '/group0/group1/table2', '/group0/group1/var1', '/group0/group1/var4'
+        """
+        self.assertIsInstance(self.h5file.root._v_groups, dict)
+        group_names = {'group0'}
+        names = {k for k, v in self.h5file.root._v_groups.iteritems()}
+        self.assertEqual(group_names, names)
+        groups = list(self.h5file.root._v_groups.itervalues())
+        self.assertEqual(len(groups), len(group_names))
+
+        for group in groups:
+            with self.subTest(name=group._v_name):
+                self.assertIn(group._v_name, group_names)
+
+        if common.verbose:
+            print("Group._v_groups test passed")
+
+
+class DeepTreeTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Checks for deep hierarchy levels in PyTables trees."""
 
     def setUp(self):
-        super(DeepTreeTestCase, self).setUp()
+        super().setUp()
 
         # Here we put a more conservative limit to deal with more platforms
         # With maxdepth = 64 this test would take less than 40 MB
@@ -596,7 +619,7 @@ class DeepTreeTestCase(common.TempFileMixin, TestCase):
     def _check_tree(self, filename):
         # Open the previous HDF5 file in read-only mode
 
-        with tables.open_file(filename, mode="r") as h5file:
+        with tb.open_file(filename, mode="r") as h5file:
             group = h5file.root
             if common.verbose:
                 print("\nDepth reading progress: ", end=' ')
@@ -625,10 +648,10 @@ class DeepTreeTestCase(common.TempFileMixin, TestCase):
     def test01a_copyDeepTree(self):
         """Copy of a large depth object tree."""
 
-        self.h5file = tables.open_file(self.h5fname, mode="r")
+        self.h5file = tb.open_file(self.h5fname, mode="r")
         h5fname2 = tempfile.mktemp(".h5")
         try:
-            with tables.open_file(h5fname2, mode="w") as h5file2:
+            with tb.open_file(h5fname2, mode="w") as h5file2:
                 if common.verbose:
                     print("\nCopying deep tree...")
 
@@ -638,18 +661,17 @@ class DeepTreeTestCase(common.TempFileMixin, TestCase):
 
             self._check_tree(h5fname2)
         finally:
-            if os.path.exists(h5fname2):
-                os.remove(h5fname2)
+            if Path(h5fname2).is_file():
+                Path(h5fname2).unlink()
 
     def test01b_copyDeepTree(self):
         """Copy of a large depth object tree with small node cache."""
 
-        self.h5file = tables.open_file(self.h5fname, mode="r",
-                                       node_cache_slots=10)
+        self.h5file = tb.open_file(self.h5fname, mode="r", node_cache_slots=10)
         h5fname2 = tempfile.mktemp(".h5")
         try:
-            with tables.open_file(h5fname2, mode="w",
-                                  node_cache_slots=10) as h5file2:
+            with tb.open_file(h5fname2, mode="w",
+                              node_cache_slots=10) as h5file2:
                 if common.verbose:
                     print("\nCopying deep tree...")
 
@@ -659,18 +681,17 @@ class DeepTreeTestCase(common.TempFileMixin, TestCase):
 
             self._check_tree(h5fname2)
         finally:
-            if os.path.exists(h5fname2):
-                os.remove(h5fname2)
+            if Path(h5fname2).is_file():
+                Path(h5fname2).unlink()
 
     def test01c_copyDeepTree(self):
         """Copy of a large depth object tree with no node cache."""
 
-        self.h5file = tables.open_file(self.h5fname, mode="r",
-                                       node_cache_slots=0)
+        self.h5file = tb.open_file(self.h5fname, mode="r", node_cache_slots=0)
         h5fname2 = tempfile.mktemp(".h5")
         try:
-            with tables.open_file(h5fname2, mode="w",
-                                  node_cache_slots=0) as h5file2:
+            with tb.open_file(h5fname2, mode="w",
+                              node_cache_slots=0) as h5file2:
                 if common.verbose:
                     print("\nCopying deep tree...")
 
@@ -680,19 +701,19 @@ class DeepTreeTestCase(common.TempFileMixin, TestCase):
 
             self._check_tree(h5fname2)
         finally:
-            if os.path.exists(h5fname2):
-                os.remove(h5fname2)
+            if Path(h5fname2).is_file():
+                Path(h5fname2).unlink()
 
-    @unittest.skipUnless(common.heavy, 'only in heavy mode')
+    @common.unittest.skipUnless(common.heavy, 'only in heavy mode')
     def test01d_copyDeepTree(self):
         """Copy of a large depth object tree with static node cache."""
 
-        self.h5file = tables.open_file(self.h5fname, mode="r",
-                                       node_cache_slots=-256)
+        self.h5file = tb.open_file(self.h5fname, mode="r",
+                                   node_cache_slots=-256)
         h5fname2 = tempfile.mktemp(".h5")
         try:
-            with tables.open_file(h5fname2, mode="w",
-                                  node_cache_slots=-256) as h5file2:
+            with tb.open_file(h5fname2, mode="w",
+                              node_cache_slots=-256) as h5file2:
                 if common.verbose:
                     print("\nCopying deep tree...")
 
@@ -702,11 +723,11 @@ class DeepTreeTestCase(common.TempFileMixin, TestCase):
 
             self._check_tree(h5fname2)
         finally:
-            if os.path.exists(h5fname2):
-                os.remove(h5fname2)
+            if Path(h5fname2).is_file():
+                Path(h5fname2).unlink()
 
 
-class WideTreeTestCase(common.TempFileMixin, TestCase):
+class WideTreeTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Checks for maximum number of children for a Group."""
 
     def test00_Leafs(self):
@@ -742,14 +763,14 @@ class WideTreeTestCase(common.TempFileMixin, TestCase):
         if common.verbose:
             print()
 
-        t1 = time.time()
+        t1 = clock()
         a = [1, 1]
 
         # Open the previous HDF5 file in read-only mode
         self._reopen()
         if common.verbose:
             print("\nTime spent opening a file with %d arrays: %s s" %
-                  (maxchildren, time.time()-t1))
+                  (maxchildren, clock()-t1))
             print("\nChildren reading progress: ", end=' ')
 
         # Get the metadata on the previosly saved arrays
@@ -801,13 +822,13 @@ class WideTreeTestCase(common.TempFileMixin, TestCase):
         if common.verbose:
             print()
 
-        t1 = time.time()
+        t1 = clock()
 
         # Open the previous HDF5 file in read-only mode
         self._reopen()
         if common.verbose:
             print("\nTime spent opening a file with %d groups: %s s" %
-                  (maxchildren, time.time()-t1))
+                  (maxchildren, clock()-t1))
             print("\nChildren reading progress: ", end=' ')
 
         # Get the metadata on the previosly saved arrays
@@ -823,11 +844,11 @@ class WideTreeTestCase(common.TempFileMixin, TestCase):
             print()  # This flush the stdout buffer
 
 
-class HiddenTreeTestCase(common.TempFileMixin, TestCase):
+class HiddenTreeTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Check for hidden groups, leaves and hierarchies."""
 
     def setUp(self):
-        super(HiddenTreeTestCase, self).setUp()
+        super().setUp()
 
         self.visible = []  # list of visible object paths
         self.hidden = []  # list of hidden object paths
@@ -922,7 +943,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
         for group in self.h5file.walk_groups('/'):
             pathname = group._v_pathname
             self.assertNotIn(pathname, hidden,
-                            "Walked across hidden group ``%s``." % pathname)
+                             f"Walked across hidden group ``{pathname}``.")
 
     def test03_walkNodes(self):
         """Hidden node absence in `File.walk_nodes()`."""
@@ -932,7 +953,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
         for node in self.h5file.walk_nodes('/'):
             pathname = node._v_pathname
             self.assertNotIn(pathname, hidden,
-                            "Walked across hidden node ``%s``." % pathname)
+                             f"Walked across hidden node ``{pathname}``.")
 
     def test04_listNodesVisible(self):
         """Listing visible nodes under a visible group (list_nodes)."""
@@ -942,7 +963,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
         for node in self.h5file.list_nodes('/g'):
             pathname = node._v_pathname
             self.assertNotIn(pathname, hidden,
-                            "Listed hidden node ``%s``." % pathname)
+                             f"Listed hidden node ``{pathname}``.")
 
     def test04b_listNodesVisible(self):
         """Listing visible nodes under a visible group (iter_nodes)."""
@@ -952,7 +973,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
         for node in self.h5file.iter_nodes('/g'):
             pathname = node._v_pathname
             self.assertNotIn(pathname, hidden,
-                            "Listed hidden node ``%s``." % pathname)
+                             f"Listed hidden node ``{pathname}``.")
 
     def test05_listNodesHidden(self):
         """Listing visible nodes under a hidden group (list_nodes)."""
@@ -966,7 +987,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
             if pathname == node_to_find:
                 found_node = True
             self.assertIn(pathname, hidden,
-                            "Listed hidden node ``%s``." % pathname)
+                          f"Listed hidden node ``{pathname}``.")
 
         self.assertTrue(found_node,
                         "Hidden node ``%s`` was not listed." % node_to_find)
@@ -983,7 +1004,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
             if pathname == node_to_find:
                 found_node = True
             self.assertIn(pathname, hidden,
-                            "Listed hidden node ``%s``." % pathname)
+                          f"Listed hidden node ``{pathname}``.")
 
         self.assertTrue(found_node,
                         "Hidden node ``%s`` was not listed." % node_to_find)
@@ -994,7 +1015,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
         """Reopening a file with hidden nodes."""
 
         self.h5file.close()
-        self.h5file = tables.open_file(self.h5fname)
+        self.h5file = tb.open_file(self.h5fname)
         self.test00_objects()
 
     def test07_move(self):
@@ -1016,7 +1037,7 @@ class HiddenTreeTestCase(common.TempFileMixin, TestCase):
         self.assertNotIn('/g/_p_a', self.h5file)
 
 
-class CreateParentsTestCase(common.TempFileMixin, TestCase):
+class CreateParentsTestCase(common.TempFileMixin, common.PyTablesTestCase):
     """Test the ``createparents`` flag.
 
     These are mainly for the user interface.  More thorough tests on the
@@ -1024,10 +1045,10 @@ class CreateParentsTestCase(common.TempFileMixin, TestCase):
 
     """
 
-    filters = tables.Filters(complevel=4)  # simply non-default
+    filters = tb.Filters(complevel=4)  # simply non-default
 
     def setUp(self):
-        super(CreateParentsTestCase, self).setUp()
+        super().setUp()
         self.h5file.create_array('/', 'array', [1])
         self.h5file.create_group('/', 'group', filters=self.filters)
 
@@ -1047,11 +1068,11 @@ class CreateParentsTestCase(common.TempFileMixin, TestCase):
 
     def test01_inside(self):
         """Placing a node inside a nonexistent child of itself."""
-        self.assertRaises(tables.NodeError, self.h5file.move_node,
+        self.assertRaises(tb.NodeError, self.h5file.move_node,
                           '/group', '/group/foo/bar',
                           createparents=True)
         self.assertNotIn('/group/foo', self.h5file)
-        self.assertRaises(tables.NodeError, self.h5file.copy_node,
+        self.assertRaises(tb.NodeError, self.h5file.copy_node,
                           '/group', '/group/foo/bar',
                           recursive=True, createparents=True)
         self.assertNotIn('/group/foo', self.h5fname)
@@ -1066,16 +1087,16 @@ class CreateParentsTestCase(common.TempFileMixin, TestCase):
 
 
 def suite():
-    theSuite = unittest.TestSuite()
+    theSuite = common.unittest.TestSuite()
     # This counter is useful when detecting memory leaks
     niter = 1
 
     for i in range(niter):
-        theSuite.addTest(unittest.makeSuite(TreeTestCase))
-        theSuite.addTest(unittest.makeSuite(DeepTreeTestCase))
-        theSuite.addTest(unittest.makeSuite(WideTreeTestCase))
-        theSuite.addTest(unittest.makeSuite(HiddenTreeTestCase))
-        theSuite.addTest(unittest.makeSuite(CreateParentsTestCase))
+        theSuite.addTest(common.unittest.makeSuite(TreeTestCase))
+        theSuite.addTest(common.unittest.makeSuite(DeepTreeTestCase))
+        theSuite.addTest(common.unittest.makeSuite(WideTreeTestCase))
+        theSuite.addTest(common.unittest.makeSuite(HiddenTreeTestCase))
+        theSuite.addTest(common.unittest.makeSuite(CreateParentsTestCase))
 
     return theSuite
 
@@ -1083,4 +1104,4 @@ def suite():
 if __name__ == '__main__':
     common.parse_argv(sys.argv)
     common.print_versions()
-    unittest.main(defaultTest='suite')
+    common.unittest.main(defaultTest='suite')
